@@ -4,11 +4,12 @@
 from warnings import warn
 
 import pkg_resources
+
 from apppath import AppPath
 
 __project__ = "Warg"
 __author__ = "Christian Heider Nielsen"
-__version__ = "0.6.1"
+__version__ = "0.6.2"
 __doc__ = r"""
 Created on 27/04/2019
 
@@ -69,8 +70,7 @@ else:
 
 
 def get_version(append_time: Any = DEVELOP) -> str:
-    """
-    """
+    """ """
     import datetime
     import os
 
@@ -87,11 +87,7 @@ def get_version(append_time: Any = DEVELOP) -> str:
             # Most git tags are prefixed with 'v' (example: v1.2.3) this is
             # never desirable for artifact repositories, so we strip the
             # leading 'v' if it's present.
-            version = (
-                version[1:]
-                if isinstance(version, str) and version.startswith("v")
-                else version
-            )
+            version = version[1:] if isinstance(version, str) and version.startswith("v") else version
         else:
             # Default version is an ISO8601 compliant datetime. PyPI doesn't allow
             # the colon ':' character in its versions, and time is required to allow
@@ -103,9 +99,7 @@ def get_version(append_time: Any = DEVELOP) -> str:
             #
             # Publications using datetime versions should only be made from master
             # to represent the HEAD moving forward.
-            warn(
-                f"Environment variable VERSION is not set, only using datetime: {date_version}"
-            )
+            warn(f"Environment variable VERSION is not set, only using datetime: {date_version}")
 
             # warn(f'Environment variable VERSION is not set, only using timestamp: {version}')
 
