@@ -276,9 +276,7 @@ class NamedOrderedDictionary(MutableMapping):
             # assert isinstance(value,Sequence), f'values must be of type Sequence, was {type(value)},' \
             #                                f' distribution is not supported'
             if isinstance(value, Sequence):
-                assert len(key) == len(
-                    value
-                ), f"number of keys {len(key)} are not equal values {len(value)}"
+                assert len(key) == len(value), f"number of keys {len(key)} are not equal values {len(value)}"
                 for a, v in zip(key, value):
                     self.__dict__[a] = v
             else:
